package introspection;

public interface Fraction {
	public int getNumerator();
	public int getDenominator();
	public void setNumerator(int n);
	public void setDenominator(int d);
	
	public Fraction addTo(Fraction f);
	public Fraction multTo(Fraction f);
	public Fraction subTo(Fraction f);
	public Fraction divBy(Fraction f);
	public Fraction inverse();
	public Fraction opposite();
	

}
