package introspection;

public class Test {

	/**
	 * @param args
	 */
	public static void main(String[] args) {
		Fraction p=ProxyFactory.getInstance(new ConcreteFraction(1,3));
		Fraction q=ProxyFactory.getInstance(new ConcreteFraction(1,6));
		System.out.println(p.addTo(q));
	}

}
