package introspection;

import java.lang.reflect.Proxy;

@Exercice(5)
public class ProxyFactory {
	static private Class<Fraction> cf=Fraction.class;

	
	public static Fraction getInstance(Fraction f){
		Object o= Proxy.newProxyInstance(cf.getClassLoader(),
										new Class<?>[] {cf},
										new Handler(f));
		return (Fraction) o;
	}

}
